@@ -23,8 +23,9 @@ import re
 import socket
 import subprocess
 import time
+from collections.abc import Iterable, Mapping
 from tempfile import NamedTemporaryFile, TemporaryDirectory
-from typing import TYPE_CHECKING, Any, Iterable, Mapping
+from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
     import pandas as pd
@@ -55,7 +56,8 @@ def get_context_from_env_var() -> dict[Any, Any]:
 
 
 class HiveCliHook(BaseHook):
-    """Simple wrapper around the hive CLI.
+    """
+    Simple wrapper around the hive CLI.
 
     It also supports the ``beeline``
     a lighter CLI that runs JDBC and is replacing the heavier
@@ -410,9 +412,10 @@ class HiveCliHook(BaseHook):
         if pandas_kwargs is None:
             pandas_kwargs = {}
 
-        with TemporaryDirectory(prefix="airflow_hiveop_") as tmp_dir, NamedTemporaryFile(
-            dir=tmp_dir, mode="w"
-        ) as f:
+        with (
+            TemporaryDirectory(prefix="airflow_hiveop_") as tmp_dir,
+            NamedTemporaryFile(dir=tmp_dir, mode="w") as f,
+        ):
             if field_dict is None:
                 field_dict = _infer_field_types_from_df(df)
 
@@ -645,7 +648,8 @@ class HiveMetastoreHook(BaseHook):
             return client.check_for_named_partition(schema, table, partition_name)
 
     def get_table(self, table_name: str, db: str = "default") -> Any:
-        """Get a metastore table object.
+        """
+        Get a metastore table object.
 
         >>> hh = HiveMetastoreHook()
         >>> t = hh.get_table(db="airflow", table_name="static_babynames")
